import os

import yaml

def load_config():
  config_path = os.environ.get("LOGVIEW_CONFIG", "/etc/logview.yaml")

  if not os.access(config_path, os.R_OK):
    return yaml.load(default_logview_yaml(), Loader=yaml.FullLoader)

  with open(config_path, 'rb') as f:
    return yaml.load(f.read(), Loader=yaml.FullLoader)

def default_logview_yaml():
  return """
  auth_token:
  server_ssl_cert:
  server_ssl_key:
  log_expiration_seconds: 86400
  targets:
    coordinator:
      path: /mnt/var/sv/coordinator/current
      label: Coordinator
      description: The coordinator is responsible for segment management and distribution
    overlord:
      path: /mnt/var/sv/overlord/current
      label: Overlord
      description: The overlord is responsible for coordination and management of indexing tasks
    broker:
      path: /mnt/var/sv/broker/current
      label: Broker
      description: The broker accepts queries, issues subqueries to historicals, and merges the results to return a response to the client
    router:
      path: /mnt/var/sv/router/current
      label: Router
      description: The router intelligently forwards queries and API requests to the appropriate service and serves the Druid Console
    pivot:
      path: /mnt/var/sv/pivot/current
      label: Pivot
      description: Imply's Druid-optimized drag and drop UI for intuitive and interactive data exploration
    historical:
      path: /mnt/var/sv/historical/current
      label: Historical
      description: The historical service manages a subset of segments and is responsible for answering subqueries on its slice of data
    middle-manager:
      path: /mnt/var/sv/middleManager/current
      label: Middle Manager
      description: The middle manager receives indexing assignments from the overlord and spawns child processes to ingest data into segments
    cfn-init:
      path: /var/log/cfn-init.log
      label: CloudFormation Init
      description: Runs when an EC2 instance starts up and mounts volumes, configures networking, fetches configurations, and starts Imply services
    imply:
      path: /etc/service/imply/log/main/current
      label: Druid Supervise
      description: A supervision service that manages the lifecycle of Druid services
    grove:
      path: /etc/service/grove-agent/log/main/current
      label: Grove
      description: An orchestration agent used to receive pushed distributions and configurations, and manage the registration and state of services
    zk:
      path: /etc/service/zk-server/log/main/current
      label: ZooKeeper
      description: A highly-available service for maintaining configuration information and providing distributed synchronization
  """
